.. _sdss_access-changelog:

==========
Change Log
==========

This document records the main changes to the sdss_access code.

0.2.5 (unreleased)
------------------

0.2.4 (2017-12-05)
------------------

Added
-----
* Method to lookup the keyword arguments needed for a given path name
* Sphinx plugin to auto document the sdss_access path definitions

.. _changelog-0.2.3:

0.2.3 (2017-12-02)
------------------

Added
^^^^^
* Added new Sphinx documentation and wrote some stuff

Changed
^^^^^^^
* Migrated sdss_access over into the cookiecutter model

